aboutsummaryrefslogtreecommitdiff
path: root/src/lineacc.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/lineacc.c')
-rw-r--r--src/lineacc.c46
1 files changed, 23 insertions, 23 deletions
diff --git a/src/lineacc.c b/src/lineacc.c
index c5b4759..84dd719 100644
--- a/src/lineacc.c
+++ b/src/lineacc.c
@@ -1,4 +1,4 @@
/* grecs - Gray's Extensible Configuration System
Copyright (C) 2007-2016 Sergey Poznyakoff
Grecs is free software; you can redistribute it and/or modify it
@@ -17,72 +17,72 @@
#ifdef HAVE_CONFIG_H
# include <config.h>
#endif
-#include <grecs.h>
+#include <argot.h>
#include <wordsplit.h>
-static struct grecs_txtacc *line_acc;
+static struct argot_txtacc *line_acc;
void
-grecs_line_acc_create()
+argot_line_acc_create()
{
- line_acc = grecs_txtacc_create();
+ line_acc = argot_txtacc_create();
}
void
-grecs_line_acc_free()
+argot_line_acc_free()
{
- grecs_txtacc_free(line_acc);
+ argot_txtacc_free(line_acc);
line_acc = NULL;
}
void
-grecs_line_acc_grow_char(int c)
+argot_line_acc_grow_char(int c)
{
char t = c;
- grecs_txtacc_grow(line_acc, &t, 1);
+ argot_txtacc_grow(line_acc, &t, 1);
}
int
-grecs_line_acc_grow_char_unescape(int c)
+argot_line_acc_grow_char_unescape(int c)
{
if (c != '\n') {
int uc = wordsplit_c_unquote_char(c);
- grecs_line_acc_grow_char(uc ? uc : c);
+ argot_line_acc_grow_char(uc ? uc : c);
return !uc;
}
return 0;
}
void
-grecs_line_acc_grow(const char *text, size_t len)
+argot_line_acc_grow(const char *text, size_t len)
{
- grecs_txtacc_grow(line_acc, text, len);
+ argot_txtacc_grow(line_acc, text, len);
}
/* Same, but unescapes the last character from text */
void
-grecs_line_acc_grow_unescape_last(char *text, size_t len,
- grecs_locus_t const *loc)
+argot_line_acc_grow_unescape_last(char *text, size_t len,
+ argot_locus_t const *loc)
{
- grecs_txtacc_grow(line_acc, text, len - 2);
- if (grecs_line_acc_grow_char_unescape(text[len - 1]) && loc)
- grecs_warning(loc, 0,
+ argot_txtacc_grow(line_acc, text, len - 2);
+ if (argot_line_acc_grow_char_unescape(text[len - 1]) && loc)
+ argot_warning(loc, 0,
_("unknown escape sequence: '\\%c'"),
text[len - 1]);
}
void
-grecs_line_begin()
+argot_line_begin()
{
if (!line_acc)
- grecs_line_acc_create();
+ argot_line_acc_create();
}
char *
-grecs_line_finish()
+argot_line_finish()
{
- grecs_line_acc_grow_char(0);
- return grecs_txtacc_finish(line_acc, 1);
+ argot_line_acc_grow_char(0);
+ return argot_txtacc_finish(line_acc, 1);
}

Return to:
@@ -1,4 +1,4 @@
-/* grecs - Gray's Extensible Configuration System
+/* argot - Gray's Extensible Configuration System
Copyright (C) 2007-2016 Sergey Poznyakoff
Grecs is free software; you can redistribute it and/or modify it

Send suggestions and report system problems to the System administrator.